# LitMNIST

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/XavierJiezou/LitMNIST/Release)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/c2f85c8d6b8a4892b40059703f087eab)](https://www.codacy.com/gh/XavierJiezou/LitMNIST/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=XavierJiezou/LitMNIST&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/XavierJiezou/LitMNIST/branch/main/graph/badge.svg?token=AFQB7E7JID)](https://codecov.io/gh/XavierJiezou/LitMNIST)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/LitMNIST)
![PyPI - Downloads](https://img.shields.io/pypi/dm/LitMNIST)
![PyPI](https://img.shields.io/pypi/v/LitMNIST)
[![GitHub stars](https://img.shields.io/github/stars/XavierJiezou/LitMNIST)](https://github.com/XavierJiezou/LitMNIST/stargazers)
[![GitHub forks](https://img.shields.io/github/forks/XavierJiezou/LitMNIST)](https://github.com/XavierJiezou/LitMNIST/network)
[![GitHub issues](https://img.shields.io/github/issues/XavierJiezou/LitMNIST)](https://github.com/XavierJiezou/LitMNIST/issues)
[![GitHub license](https://img.shields.io/github/license/XavierJiezou/LitMNIST)](https://github.com/XavierJiezou/LitMNIST/blob/main/LICENSE)

PyTorch Lightning demo on the MNIST dataset.

## Demo

## Install

```bash
pip install litmnist
```

## Usage

`$ litmnist`

## Changelog

See [CHANGELOG.md](CHANGELOG.md)

## License

[MIT License](License)

## References

- [Python dependency management and packaging made easy.](https://github.com/python-poetry/poetry)
- [The lightweight PyTorch wrapper for high-performance AI research. Scale your models, not the boilerplate.](https://github.com/PyTorchLightning/pytorch-lightning)
